package ru.ulstu.conference.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import ru.ulstu.core.model.BaseEntity;
import ru.ulstu.user.model.User;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;

@Entity
@Table(name = "users_conference")
public class ConferenceUser extends BaseEntity {

    public enum Participation {
        INTRAMURAL("Очная"),
        EXTRAMURAL("Заочная");

        private String participationName;

        Participation(String name) {
            this.participationName = name;
        }

        public String getParticipation() {
            return participationName;
        }
    }

    public enum Deposit {
        ARTICLE("Статья"),
        REPORT("Доклад"),
        PRESENTATION("Презентация");

        private String depositName;

        Deposit(String name) {
            this.depositName = name;
        }

        public String getDeposit() {
            return depositName;
        }
    }


    @NotNull
    @Column(name = "participation", nullable = false)
    @Enumerated(value = EnumType.STRING)
    private Participation participation = Participation.INTRAMURAL;

    @NotNull
    @Column(name = "deposit", nullable = false)
    @Enumerated(value = EnumType.STRING)
    private Deposit deposit = Deposit.ARTICLE;

    @ManyToOne(optional = false)
    @JoinColumn(name = "users_id")
    private User user;

    public ConferenceUser() {
    }

    public ConferenceUser(User user) {
        this.user = user;
    }

    @JsonCreator
    public ConferenceUser(@JsonProperty("id") Integer id,
                          @JsonProperty("deposit") Participation participation,
                          @JsonProperty("deposit") Deposit deposit,
                          @JsonProperty("user") User user) {
        this.setId(id);
        this.participation = participation;
        this.deposit = deposit;
        this.user = user;
    }


    public Participation getParticipation() {
        return participation;
    }

    public void setParticipation(Participation participation) {
        this.participation = participation;
    }

    public Deposit getDeposit() {
        return deposit;
    }

    public void setDeposit(Deposit deposit) {
        this.deposit = deposit;
    }

    public User getUser() {
        return user;
    }

    public void setUser(User user) {
        this.user = user;
    }

}
